@@ -40,9 +40,9 @@ import tempfile
 import time
 
 
-DEFAULT_CHUNK_SIZE = 16384
+DEFAULT_CHUNK_SIZE = 16384  # block size in HFS+; 4X the block size in ext4
 DOT_THRESHOLD = 200
-VERSION = (0, 9, 0)
+VERSION = (0, 9, 2)
 IGNORED_FILE_SYSTEM_ERRORS = {errno.ENOENT, errno.EACCES}
 FSENCODING = sys.getfilesystemencoding()
 
@@ -112,17 +112,10 @@ def list_existing_paths(directory, expected=(), ignored=(), follow_links=False):
             try:
                 p_uni = p.decode(FSENCODING)
             except UnicodeDecodeError:
-                try:
-                    print(
-                        "warning: cannot decode file name:",
-                        path,
-                        file=sys.stderr,
-                    )
-                except UnicodeDecodeError:
-                    # yup, even printing the filename might fail in certain
-                    # occasions
-                    pass
-
+                binary_stderr = getattr(sys.stderr, 'buffer', sys.stderr)
+                binary_stderr.write(b"warning: cannot decode file name: ")
+                binary_stderr.write(p)
+                binary_stderr.write(b"\n")
                 continue
 
             try:
@@ -193,7 +186,7 @@ class Bitrot(object):
         )
 
         for p in paths:
-            p_uni = p.decode('utf8')
+            p_uni = p.decode(FSENCODING)
             try:
                 st = os.stat(p)
             except OSError as ex:
@@ -201,14 +194,13 @@ class Bitrot(object):
                     # The file disappeared between listing existing paths and
                     # this run or is (temporarily?) locked with different
                     # permissions. We'll just skip it for now.
-                    if self.verbosity:
-                        print(
-                            '\rwarning: `{}` is currently unavailable for '
-                            'reading: {}'.format(
-                                p_uni, ex,
-                            ),
-                            file=sys.stderr,
-                        )
+                    print(
+                        '\rwarning: `{}` is currently unavailable for '
+                        'reading: {}'.format(
+                            p_uni, ex,
+                        ),
+                        file=sys.stderr,
+                    )
                     continue
 
                 raise   # Not expected? https://github.com/ambv/bitrot/issues/
@@ -222,13 +214,12 @@ class Bitrot(object):
             try:
                 new_sha1 = sha1(p, self.chunk_size)
             except (IOError, OSError) as e:
-                if self.verbosity:
-                    print(
-                        '\rwarning: cannot compute hash of {} [{}]'.format(
-                            p, errno.errorcode[e.args[0]],
-                        ),
-                        file=sys.stderr,
-                    )
+                print(
+                    '\rwarning: cannot compute hash of {} [{}]'.format(
+                        p, errno.errorcode[e.args[0]],
+                    ),
+                    file=sys.stderr,
+                )
                 continue
 
             cur.execute('SELECT mtime, hash, timestamp FROM bitrot WHERE '
@@ -328,17 +319,22 @@ class Bitrot(object):
                 print('{} entries new:'.format(len(new_paths)))
                 new_paths.sort()
                 for path in new_paths:
-                    print(' ', path)
+                    print(' ', path.decode(FSENCODING))
             if updated_paths:
                 print('{} entries updated:'.format(len(updated_paths)))
                 updated_paths.sort()
                 for path in updated_paths:
-                    print(' ', path)
+                    print(' ', path.decode(FSENCODING))
             if renamed_paths:
                 print('{} entries renamed:'.format(len(renamed_paths)))
                 renamed_paths.sort()
                 for path in renamed_paths:
-                    print(' from', path[0], 'to', path[1])
+                    print(
+                        ' from',
+                        path[0].decode(FSENCODING),
+                        'to',
+                        path[1].decode(FSENCODING),
+                    )
             if missing_paths:
                 print('{} entries missing:'.format(len(missing_paths)))
                 missing_paths = sorted(missing_paths)
@@ -386,18 +382,20 @@ def get_path(directory=b'.', ext=b'db'):
     return os.path.join(directory, b'.bitrot.' + ext)
 
 
-def stable_sum(bitrot_db):
+def stable_sum(bitrot_db=None):
     """Calculates a stable SHA512 of all entries in the database.
 
     Useful for comparing if two directories hold the same data, as it ignores
     timing information."""
+    if bitrot_db is None:
+        bitrot_db = get_path()
     digest = hashlib.sha512()
     conn = get_sqlite3_cursor(bitrot_db)
     cur = conn.cursor()
     cur.execute('SELECT hash FROM bitrot ORDER BY path')
     row = cur.fetchone()
     while row:
-        digest.update(row[0])
+        digest.update(row[0].encode('ascii'))
         row = cur.fetchone()
     return digest.hexdigest()
 
